@@ -16,6 +16,7 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #  =============================================================================
+
 from .quote_api import *
 from .quote_spi import *
 from .trade_api import *
@@ -26,13 +27,13 @@ from .his_quote_spi import *
 from ..protocols import MsgProto, EnumProto
 
 from . import py2pb as _pyb
-from .py2pb import ToProto, ToPyobj, ToPyobjSpec
+from .py2pb import ToProto, ToPyobj
 
 # =======================================================================================
 # = QuoteApi
 # =======================================================================================
 # QuoteSubscribe
-_pyb.RegisterConvertor(protobuf=MsgProto.Quote_QuoteRegisterMsg).Register(QuoteSubscribe)
+_pyb.RegisterConvertor(protobuf=MsgProto.Quote_QuoteSymbolsMsg).Register(QuoteSubscribe)
 
 # QrySecurityStaticReq
 _pyb.RegisterConvertor(protobuf=MsgProto.Trade_QrySecurityStaticReq).Register(QrySecurityStaticReq)
@@ -41,7 +42,7 @@ _pyb.RegisterConvertor(protobuf=MsgProto.Trade_QrySecurityStaticReq).Register(Qr
 # = QuoteSpi
 # =======================================================================================
 # QuoteRegisterAck
-_pyb.RegisterConvertor(protobuf=MsgProto.Quote_RegisterAck).SetPyHandles(
+_pyb.RegisterConvertor(protobuf=MsgProto.Quote_QuoteSubscribeUnAck).SetPyHandles(
     _pyb.PyEnumReprHandle(ret_code=EnumProto.EQuoteRetCode)
 ).Register(QuoteRegisterAck)
 
